pub enum BackUpSetting {
BackupInterval(i64),
NumBackupIter(u64),
}Variants
BackupInterval(i64)
This keyword specifies the interval, in seconds, between updates of the backup restart files. This keyword is applicable for geometry optimization, molecular dynamics, phonon or transition state search runs. A value which is less than or equal to zero indicates that no updates will be performed.
NumBackupIter(u64)