ExtraBands

Enum ExtraBands 

pub enum ExtraBands {
    NextraBands(u32),
    PercExtraBands(f64),
}
This keyword controls the percentage of extra bands in addition to the number of occupied bands. These extra bands are necessary for metals or finite temperature insulators.

Note

It is not possible to have both the NBANDS keyword and either the NEXTRA_BANDS or PERC_EXTRA_BANDS keywords present in the same input file.

Variants



NextraBands(u32)



PercExtraBands(f64)