pub enum GeomMethod {
BFGS,
LBFGS,
Delocalized,
DampedMD,
TPSD,
}Expand description
This keyword determines the method used for geometry optimization. Available options are:
- BFGS - BFGS minimization.
- LBFGS - low-memory BFGS minimization.
- Delocalized (or Delocalised) - BFGS minimization using delocalized internal coordinates instead of Cartesian coordinates.
- DampedMD - Damped molecular dynamics.
- TPSD - Two-point steepest descent.
Default
- BFGS
Example
GEOM_METHOD : DampedMD
Variants