GeomPreconditioner

Enum GeomPreconditioner 

pub enum GeomPreconditioner {
    ID,
    EXP,
    FF,
}
This keyword selects the preconditioner used for LBFGS geometry optimization. Available options are:

  • ID - identity; LBFGS is used without a preconditioner.
  • EXP - exponential preconditioner.
  • FF- forcefield based preconditioner using the scheme of Lindh et al. (1995).

The ID option’s only advantage over the BFGS minimizer is lower memory requirements. The EXP option is generally the best in terms of performance gains. The forcefield based preconditioner FF can sometimes provide further gains, although it is less stable and might require more steps to converge.

Default

ID

Example

GEOM_PRECONDITIONER : EXP

Variants



ID



EXP



FF