PSPotBetaPhiType

Enum PSPotBetaPhiType 

pub enum PSPotBetaPhiType {
    Reciprocal,
    Real,
}
This keyword controls the representation of the nonlocal part of the pseudopotential used for calculation of the <β|ϕ> overlaps. Available options are:

  • RECIPROCAL - reciprocal space nonlocal pseudopotentials
  • REAL - real space nonlocal pseudopotentials

Note

This parameter can only take the value REAL if PSPOT_NONLOCAL_TYPE is also REAL.

Default

The default is the value of PSPOT_NONLOCAL_TYPE

Example

PSPOT_BETA_PHI_TYPE : REAL

Variants



Reciprocal



Real