pub struct BandsOption { /* private fields */ }Expand description
This keyword determines the maximum number of bands at any k-point and spin.
There are three ways in which you can specify the maximum number of bands at any k-point and spin:
Directly, using NBANDS.
Indirectly, by specifying the number of extra bands in addition to the number of occupied bands using NEXTRA_BANDS.
This is the method used in the CASTEP interface.
Indirectly, by specifying the number of extra bands in addition to the number of occupied bands as a percentage of the latter value using PERC_EXTRA_BANDS.
It is not possible to have both the NBANDS keyword and either the NEXTRA_BANDS or PERC_EXTRA_BANDS keywords present in the same input file.