pub struct ElecDumpFile(/* private fields */);Expand description
This keyword determines the name of the file into which wavefunction and density data are written, periodically during electronic minimization. This file can be used as a backup and is restored with the ELEC_RESTORE_FILE parameter.
Note
If this parameter is set to NULL, no backup wavefunction or density data will be written.
Default
seedname.wvfn
Example
ELEC_DUMP_FILE : test.wvfn
Implementations