pub struct ElecEigenvalueTol {
pub tol: f64,
pub unit: Option<EnergyUnit>,
}Expand description
This keyword controls the tolerance for accepting convergence of a single eigenvalue during density mixing minimization. The difference between maximum and minimum eigenvalues over ELEC_CONVERGENCE_WIN iterations must be less than this value.
Default
The default value is the lower of 1x10-6 eV and ELEC_ENERGY_TOL*NATOMS/NBANDS, where NATOMS is the total number of atoms in the unit cell.
Fields
tol: f64unit: Option<EnergyUnit>Trait Implementations
Sourceimpl Clone for ElecEigenvalueTol
impl Clone for ElecEigenvalueTol
Sourcefn clone(&self) -> ElecEigenvalueTol
fn clone(&self) -> ElecEigenvalueTol
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElecEigenvalueTol
impl Debug for ElecEigenvalueTol
Sourceimpl Default for ElecEigenvalueTol
impl Default for ElecEigenvalueTol
Sourcefn default() -> ElecEigenvalueTol
fn default() -> ElecEigenvalueTol
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ElecEigenvalueTol
impl<'de> Deserialize<'de> for ElecEigenvalueTol
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ElecEigenvalueTol
impl Display for ElecEigenvalueTol
Sourceimpl From<f64> for ElecEigenvalueTol
impl From<f64> for ElecEigenvalueTol
Sourcefn from(value: f64) -> ElecEigenvalueTol
fn from(value: f64) -> ElecEigenvalueTol
Converts to this type from the input type.
Sourceimpl KeywordDisplay for ElecEigenvalueTol
impl KeywordDisplay for ElecEigenvalueTol
Sourceimpl PartialEq for ElecEigenvalueTol
impl PartialEq for ElecEigenvalueTol
Sourceimpl PartialOrd for ElecEigenvalueTol
impl PartialOrd for ElecEigenvalueTol
Sourceimpl Serialize for ElecEigenvalueTol
impl Serialize for ElecEigenvalueTol
impl Copy for ElecEigenvalueTol
impl StructuralPartialEq for ElecEigenvalueTol