pub struct ElecRestoreFile(/* private fields */);Expand description
This keyword specifies the name of the file from which wavefunction and density data should be restored when performing a CONTINUATION or a REUSE run. NULL means that wavefunction and density data will not be restored.
Note
The basis set and distribution for the new run must be the same as those from the run in which the data file was written.
Default
NULL
Example
ELEC_RESTORE_FILE : test.wvfn
Implementations