FineGMax

Struct FineGMax 

pub struct FineGMax {
    pub max: f64,
    pub unit: Option<InvLengthUnit>,
}
This keyword determines the maximum size of the g-vectors included in the fine grid. The fine grid is seDefault -1 a0-1 - this results in the fine and standard grids being identical

Example

FINE_GMAX : 20 1/angt up such that all g-vectors with |g| less than or equal to FINE_GMAX are included.

Fields

max: f64unit: Option<InvLengthUnit>