FiniteBasisSpacing

Struct FiniteBasisSpacing 

pub struct FiniteBasisSpacing { /* private fields */ }
This keyword determines the spacing of cutoff energies used to estimate the BasisDeDloge in automatic calculation of the finite basis set correction. Points are chosen such that the CutoffEnergy corresponds to the highest energy in the set of FiniteBasisNPoints cutoff energies.

Note

This value is only used if FINITE_BASIS_CORR : 2.