FixedNPW

Struct FixedNPW 

pub struct FixedNPW(/* private fields */);
This keyword determines whether a fixed number of plane waves (fixed size basis : TRUE) or a fixed plane wave cutoff energy (fixed quality basis : FALSE) will be used when doing a variable cell calculation. This setting affects geometry optimization with variable cell parameters and molecular dynamics with NPT or NPH ensembles.

Note

You should turn off finite basis set correction when using a fixed size basis (see FINITE_BASIS_CORR).

Default

FALSE

Example

FIXED_NPW : TRUE

Implementations

Source

impl FixedNPW

pub fn value(&self) -> bool