GeomModulusEst

Struct GeomModulusEst 

pub struct GeomModulusEst { /* private fields */ }
This keyword provides an estimate of the bulk modulus of the system. It is used to initialize the Hessian for BFGS geometry optimization with cell relaxation.

Default

500.0 GPa

Example

GEOM_MODULUS_EST : 125.4 GPa