MaxScfCycles

Struct MaxScfCycles 

pub struct MaxScfCycles(/* private fields */);
This keyword determines the maximum number of SCF cycles performed in an electronic minimization. The electronic minimization will end after this many cycles, regardless of whether the convergence criteria have been met.

Default

30

Example

MAX_SCF_CYCLES : 20

Implementations

Source

impl MaxScfCycles

pub fn value(&self) -> u32