MixCutOffEnergy

Struct MixCutOffEnergy 

pub struct MixCutOffEnergy {
    pub cutoff_energy: f64,
    pub unit: Option<EnergyUnit>,
}
This keyword determines the cutoff energy for the densities used in the density mixing scheme. The value specified determines the extent of the grid used for mixing old and new densities. Density components with wave vectors higher than that specified are not mixed.

Default

The default value is the CUT_OFF_ENERGY.

Example

MIX_CUT_OFF_ENERGY : 250.0 eV

Fields

cutoff_energy: f64unit: Option<EnergyUnit>