pub struct MixHistoryLength(/* private fields */);Expand description
This keyword determines the maximum number of densities to store in the history used during the density mixing procedure.
Default
7
Example
MIX_HISTORY_LENGTH : 5
Implementations