pub struct MixMetricQ {
pub q: f64,
pub unit: Option<InvLengthUnit>,
}Expand description
This keyword determines the weighting factor for the densities used in
the density mixing scheme.
CASTEP uses a weighting factor when evaluating scalar products of densities.
The factor depends on the wave vector q, according to:
f(q) = (q2 + q12)/q2
where q1 is the value of the MIX_METRIC_Q parameter.
CASTEP sets the value of q1 automatically if MIX_METRIC_Q is not specified.
Default
-1 - CASTEP will automatically select the appropriate value
Example
MIX_METRIC_Q : 20.0 1/ang
Fields
q: f64unit: Option<InvLengthUnit>Trait Implementations
Sourceimpl Clone for MixMetricQ
impl Clone for MixMetricQ
Sourcefn clone(&self) -> MixMetricQ
fn clone(&self) -> MixMetricQ
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MixMetricQ
impl Debug for MixMetricQ
Sourceimpl Default for MixMetricQ
impl Default for MixMetricQ
Sourcefn default() -> MixMetricQ
fn default() -> MixMetricQ
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MixMetricQ
impl<'de> Deserialize<'de> for MixMetricQ
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for MixMetricQ
impl Display for MixMetricQ
Sourceimpl From<f64> for MixMetricQ
impl From<f64> for MixMetricQ
Sourcefn from(value: f64) -> MixMetricQ
fn from(value: f64) -> MixMetricQ
Converts to this type from the input type.
Sourceimpl KeywordDisplay for MixMetricQ
impl KeywordDisplay for MixMetricQ
Sourceimpl PartialEq for MixMetricQ
impl PartialEq for MixMetricQ
Sourceimpl PartialOrd for MixMetricQ
impl PartialOrd for MixMetricQ
Sourceimpl Serialize for MixMetricQ
impl Serialize for MixMetricQ
impl Copy for MixMetricQ
impl StructuralPartialEq for MixMetricQ