pub struct Spin(/* private fields */);Expand description
This keyword determines the initial value for the number of unpaired electrons in a spin-polarized calculation. This value may be optimized during the CASTEP calculation depending on the values of SPIN_FIX and FIX_OCCUPANCY. The SPIN keyword cannot be used in conjunction with either of NUP or NDOWN keywords.
Default
0 when the total number of electrons in the system is even. 1 when the total number of electrons in the system is odd.
Implementations