pub struct Stop;Expand description
This keyword, if present, will cause the current run to be aborted as if RUN_TIME had been exceeded.
CASTEP checks the contents of the input file periodically during a run. This allows you to modify certain parameters and also to terminate the run early.
This keyword is valid only when the input file is reread. It is ignored if it is present at the start of a run.
Example
STOP