pub struct FineGMax {
pub max: f64,
pub unit: Option<InvLengthUnit>,
}Expand description
This keyword determines the maximum size of the g-vectors included in the fine grid. The fine grid is seDefault -1 a0-1 - this results in the fine and standard grids being identical
Example
FINE_GMAX : 20 1/angt up such that all g-vectors with |g| less than or equal to FINE_GMAX are included.
Fields
max: f64unit: Option<InvLengthUnit>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FineGMax
impl<'de> Deserialize<'de> for FineGMax
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl KeywordDisplay for FineGMax
impl KeywordDisplay for FineGMax
Sourceimpl PartialOrd for FineGMax
impl PartialOrd for FineGMax
impl Copy for FineGMax
impl StructuralPartialEq for FineGMax