Struct GeomFrequencyEst Copy item path Source pub struct GeomFrequencyEst {
pub est: f64 ,
pub unit: Option <FrequencyUnit >,
}Expand description This keyword provides an estimate of the average phonon frequency at the gamma
point. It is used to initialize the Hessian for BFGS geometry optimization with
ionic relaxation. One expects to achieve faster convergence of the geometry
optimization if the value is realistic. The idea is that this single number
represents the whole of the Hessian in a compact form.
The value of the estimated frequency is provided in the CASTEP output after
the geometry optimization run, and this value can be used as an input parameter
for a new calculation on a similar system. An example would be a study of
different configurations of a self-interstitial defect in silicon.
 Note
The value of the estimated frequency as returned by CASTEP should not be
interpreted as an actual frequency of any real vibrational mode.
 Default
50 THz
 Example
GEOM_FREQUENCY_EST : 17.54 THz
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.