pub struct MixCutOffEnergy {
pub cutoff_energy: f64,
pub unit: Option<EnergyUnit>,
}Expand description
This keyword determines the cutoff energy for the densities used in the density mixing scheme. The value specified determines the extent of the grid used for mixing old and new densities. Density components with wave vectors higher than that specified are not mixed.
Default
The default value is the CUT_OFF_ENERGY.
Example
MIX_CUT_OFF_ENERGY : 250.0 eV
Fields
cutoff_energy: f64unit: Option<EnergyUnit>Trait Implementations
Sourceimpl Clone for MixCutOffEnergy
impl Clone for MixCutOffEnergy
Sourcefn clone(&self) -> MixCutOffEnergy
fn clone(&self) -> MixCutOffEnergy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MixCutOffEnergy
impl Debug for MixCutOffEnergy
Sourceimpl Default for MixCutOffEnergy
impl Default for MixCutOffEnergy
Sourcefn default() -> MixCutOffEnergy
fn default() -> MixCutOffEnergy
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MixCutOffEnergy
impl<'de> Deserialize<'de> for MixCutOffEnergy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for MixCutOffEnergy
impl Display for MixCutOffEnergy
Sourceimpl From<f64> for MixCutOffEnergy
impl From<f64> for MixCutOffEnergy
Sourcefn from(value: f64) -> MixCutOffEnergy
fn from(value: f64) -> MixCutOffEnergy
Converts to this type from the input type.
Sourceimpl KeywordDisplay for MixCutOffEnergy
impl KeywordDisplay for MixCutOffEnergy
Sourceimpl PartialEq for MixCutOffEnergy
impl PartialEq for MixCutOffEnergy
Sourceimpl PartialOrd for MixCutOffEnergy
impl PartialOrd for MixCutOffEnergy
Sourceimpl Serialize for MixCutOffEnergy
impl Serialize for MixCutOffEnergy
impl Copy for MixCutOffEnergy
impl StructuralPartialEq for MixCutOffEnergy